##  Best Practice
The table below lists collections available for import. They are based on SAP LeanIX best practices for typical scenarios.
Collection Group (Product) | Collection (Use Case) | Report | Description
---|---|---|---
SAP LeanIX Application Portfolio Management | Business Capability Modelling |  |  Business capability modeling is a technique for the representation of an organization’s business anchor model independent of the organization’s structure, processes, people, or domains. Business capability models enable the discussion of strategic invest or divest. Business capabilities can serve as the structuring element to uncover redundancies in IT.
|  | Business Capability Cost | This report gives you an overview of which business capabilities are supported by which applications and how much this support costs you annually. It helps you understand the cost allocation per business capability and to analyze where costs could be reduced.
|  | Business Capability Map - View: Lifecycle | The Business Capability Map gives you a hierarchical color-coded overview of your business capabilities. Add filters and switch between different views to drill down until you find what you need, for example, business capabilities that are marked as 'End of Life'.
| Application Portfolio Management |  | Application Portfolio Management is the practice of governing and optimizing inventories of software applications to achieve precise business objectives. This is accomplished by creating transparent overviews of IT application landscapes to evaluate IT costs, standardize software throughout business units and promote agility and innovation.
|  | Application Portfolio - Axis: Functional fit vs. technical fit | The Application Portfolio Report helps you identify applications that need your attention. Add filters and switch between different views to drill down until you find what you need, for example, 'Active' applications that are business critical but have insufficient technical fit.
|  | Application Landscape - View: Lifecycle | The Application Landscape report gives you a color-coded overview of your IT landscape. Add filters and switch between different views to drill down until you find what you need, for example, applications used by a business capability, process, or user group that are 'End of Life'.
|  | Application Matrix - View: Lifecycle | The Application Matrix report gives you a color-coded overview of your applications, business capabilities, and user groups. Add filters and switch between different views to drill down until you find what you need, for example, 'Mission Critical' IT components used by specific business capabilities and user groups.
|  | Application Roadmap - View: Lifecycle | The Application Roadmap gives you a Lifecycle view of 'Planned', 'Phased in', 'Active', or 'Phased out' Applications. You can also apply a drill down, e.g. by 'Children' or 'IT Components', or cluster the Applications by user group, business capability, and more.
|  | Application Usage | The Application Usage report shows you which applications are used by which user group. Zoom in for a better view of your region of interest.
|  | Application Sourcing | The Application Sourcing report shows you which IT components are used by which user group. Zoom in for a better view of your region of interest.
| Application Rationalization |  | Application portfolio rationalization is the act of streamlining the existing application portfolio with an explicit goal of improving efficiency, reducing complexity, and lowering the total cost of ownership (TCO) through a myriad of processes.
|  | Application Landscape - View: TIME | The Application Landscape report gives you a color-coded overview of your IT landscape by TIME model classification.
|  | Application Matrix - TIME | The Application Matrix report gives you a color-coded overview of your IT landscape by TIME model classification.
|  | Application Lifecycle & Age | The Lifecycle report lets you visualize 'Active' or 'Phased Out' Applications at any point in time, while the Age Structure report shows you how many of the current applications have entered, or will be entering, the status 'Active' each year.
|  | Application Roadmap | The Application Roadmap gives you a Lifecycle view of 'Planned', 'Phased in', 'Active', or 'Phased out' Applications. You can also apply a drill down, e.g. by 'Children' or 'IT Components', or cluster the applications by user group, business capability, and more.
| Integration & Data Architecture |  | Integration Architecture (IA) is a major part of every company's IT landscape that simplifies the integration of numerous IT components and enables you to trace data flows between applications.
|  | Interface Circle Map | The Interface Circle Map report shows you how different interfaces and applications are linked to each other. Group them alphabetically or by business capabilities and visualize connections between interfaces, provided interfaces, or consumed interfaces.
|  | Application Landscape - View: Data Classification | The Application Landscape report gives you a color-coded overview of your IT landscape based on the data classification of the underlying data objects.
|  | Application Matrix - View: Data Classification | The Application Matrix report gives you a color-coded overview of your applications, business capabilities, and user groups based on the data classification of the underlying data objects.
| Cost Management |  | Effectively reduce costs, paving the way for a successful business future. Identify excess funds that could be used elsewhere.
|  | Provider Cost | The Provider Cost report shows you the cost allocation per provider, either as a pie chart or in the table view.
|  | Business Capability Cost | This report gives you an overview of which business capabilities are supported by which applications and how much this support costs you annually. It helps you understand the cost allocation per business capability and to analyze where costs could be reduced.
|  | Application Landscape - View: Total annual cost | The Application Landscape report gives you a color-coded overview of your IT landscape based on the aggregated total annual cost of underlying IT components.
SAP LeanIX Technology Risk and Compliance | Obsolescence Risk Management |  | Obsolescence risk is a factor for all companies. Identify risks associated with running obsolete technology, introduce new technology, or retire existing, legacy applications and IT components.
|  | Application Landscape - View: Obsolescence: Aggregated Risk | The Application Landscape report gives you a color-coded overview of your IT landscape based on the aggregated obsolescence risk of all underlying IT components.
|  | IT Component Landscape - View: Lifecycle | The IT Component Landscape report gives you a color-coded overview of your IT Components. Add filters and switch between different views to drill down until you find what you need, for example, 'Applications: Functional Fit' that use 'End of Life' IT Components.
|  | IT Component Roadmap | The IT Component Roadmap gives you a Lifecycle view of 'Planned', 'Phased in', 'Active', or 'Phased out' IT Components. You can also apply a drill down, e.g. by 'Children' or 'IT Components' or cluster by Application, User Group, and more.
| Technology Adoption & Standards |  |  The use of standardized information technology in large corporations has measurable benefits: reduced training time and costs; lower support and maintenance costs; better bargaining power with a smaller number of vendors; and enhanced communication. Standardization also often goes hand-in-hand with centralization — the process of giving your IT department more control over purchases of hardware and software, as any piece of software equipment added to an IT system requires maintenance, staff training, repairs, patches, upgrades, etc.
|  | IT Component Landscape - View: Lifecycle | The IT Component Landscape report gives you a color-coded overview of your IT Components by lifecycle.
|  | IT Component Landscape - View: Technical Stack: Resource classification | The IT Component Landscape report gives you a color-coded overview of your IT Components by classification of the underlying resources.
|  | IT Component Location | The IT Component Location report shows you which IT Components are used by which Country or Location. Zoom in for a better view of your region of interest.
|  | Provider Portfolio | The Provider Portfolio Report groups Providers according to their 'Criticality' and 'Quality'. It can help you identify Providers that need to be replaced or renewed.
| Vendor Risk Management |  | Vendor risk management (VRM) is the process of ensuring that the use of service providers and IT suppliers does not create an unacceptable potential for business disruption or a negative impact on business performance.
|  | Provider Portfolio | The Provider Portfolio Report groups Providers according to their 'Criticality' and 'Quality'. It can help you identify Providers that need to be replaced or renewed.


